@@ -45,6 +45,7 @@ import multiprocessing
 import os
 import re
 import socket
+import time
 from multiprocessing.dummy import Pool as ThreadPool
 
 import docker
@@ -305,7 +306,16 @@ class DockerTagClass(TagClass):
         while retries < 20:
             try:
                 r = _request_get(self._docker_base + "/" + combined_repo_name + "/tags")
-                break
+                if r.status_code == 429:
+                    # Docker returns 429 if we access it too fast too many times.
+                    # If it happends, delay 60 seconds, and try again, up to 19 times.
+                    log.debug(
+                        "Too many docker gets too fast, wait 1 min: {}, repo {}".format(retries, combined_repo_name)
+                    )
+                    time.sleep(60)
+                    retries = retries + 1
+                else:
+                    break
             except requests.HTTPError as excinfo:
                 log.debug("Fetching Docker Hub tags. {}".format(excinfo))
                 retries = retries + 1
@@ -314,6 +324,11 @@ class DockerTagClass(TagClass):
                     return
 
         log.debug("r.status_code = {}, ok={}".format(r.status_code, r.status_code == requests.codes.ok))
+        if r.status_code == 429:
+            # Speed throttling in effect. Cancel program
+            raise requests.HTTPError(
+                "Speed throttling in effect. To fast accessing dockerhub for tags.\n {}".format(r.text)
+            )
         if r.status_code == requests.codes.ok:
             raw_tags = r.text
             raw_tags = raw_tags.replace("}]", "")
